Module: Ecoportal::API::GraphQL::Concerns::FragmentDefinitions::InstanceMethods
- Defined in:
- lib/ecoportal/api/graphql/concerns/fragment_definitions.rb
Instance Attribute Summary collapse
-
#client ⇒ Object
readonly
Returns the value of attribute client.
-
#fragments ⇒ Object
readonly
Returns the value of attribute fragments.
Instance Method Summary collapse
-
#define(sym, heredoc, namespace: nil) ⇒ Object
Returns the raw fragment string for the given symbol.
- #initialize(client) ⇒ Object
Instance Attribute Details
#client ⇒ Object (readonly)
Returns the value of attribute client.
45 46 47 |
# File 'lib/ecoportal/api/graphql/concerns/fragment_definitions.rb', line 45 def client @client end |
#fragments ⇒ Object (readonly)
Returns the value of attribute fragments.
45 46 47 |
# File 'lib/ecoportal/api/graphql/concerns/fragment_definitions.rb', line 45 def fragments @fragments end |
Instance Method Details
#define(sym, heredoc, namespace: nil) ⇒ Object
Returns the raw fragment string for the given symbol. The namespace parameter is retained for API compatibility but has no effect.
54 55 56 |
# File 'lib/ecoportal/api/graphql/concerns/fragment_definitions.rb', line 54 def define(sym, heredoc, namespace: nil) # rubocop:disable Lint/UnusedMethodArgument heredoc end |
#initialize(client) ⇒ Object
47 48 49 50 |
# File 'lib/ecoportal/api/graphql/concerns/fragment_definitions.rb', line 47 def initialize(client) @client = client parse end |