Class: Ecoportal::API::GraphQL::Input::LocationStructure::UpdateCommand

Inherits:
Ecoportal::API::GraphQL::Interface::LocationStructure::Command show all
Defined in:
lib/ecoportal/api/graphql/input/location_structure/update_command.rb

Constant Summary

Constants included from Common::GraphQL::Model::Diffable

Common::GraphQL::Model::Diffable::DIFF_CLASS

Instance Method Summary collapse

Methods inherited from Ecoportal::API::GraphQL::Interface::LocationStructure::Command

#keys, #set_values, #target_ids

Methods included from Concerns::SnakeCamelAccess

#method_missing, #respond_to_missing?

Methods included from Common::GraphQL::Model::AsInput

#as_input, included

Methods included from Common::GraphQL::Model::Diffable

#as_update, #dirty?

Methods included from Common::GraphQL::ClassHelpers

included

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Ecoportal::API::GraphQL::Concerns::SnakeCamelAccess

Instance Method Details

#classificationIdsObject

Effective classification ids: the new value if one was set, otherwise the current value stored under classificationIds.



21
22
23
24
25
# File 'lib/ecoportal/api/graphql/input/location_structure/update_command.rb', line 21

def classificationIds
  return doc["classificationIds"] if newClassificationIds.nil? || newClassificationIds.empty?

  newClassificationIds
end

#nameObject

Effective name: the new value if one was set, otherwise the current value stored under name.



13
14
15
16
17
# File 'lib/ecoportal/api/graphql/input/location_structure/update_command.rb', line 13

def name
  return doc["name"] if newName.nil?

  newName
end