Class: Ecoportal::API::GraphQL::Logic::BaseQuery
- Inherits:
-
Object
- Object
- Ecoportal::API::GraphQL::Logic::BaseQuery
- Includes:
- Common::GraphQL::ClassHelpers
- Defined in:
- lib/ecoportal/api/graphql/logic/base_query.rb
Instance Attribute Summary collapse
-
#base_path ⇒ Object
readonly
Returns the value of attribute base_path.
-
#client ⇒ Object
readonly
Returns the value of attribute client.
Class Method Summary collapse
- .accepted_params(*keys) ⇒ Object
- .clear_accepted_params ⇒ Object
-
.field_name(str = nil) ⇒ Object
Used to obtain the full
pathin the GraphQL query by usingbase_path. - .slice_params(kargs) ⇒ Object
Instance Method Summary collapse
- #access_point(path = []) ⇒ Object
-
#initialize(client, path: nil, base_path: []) ⇒ BaseQuery
constructor
A new instance of BaseQuery.
-
#path(field_name = self.class.field_name) ⇒ Object
Resolves the
pathby usingpathorbase_path+class.field_name. -
#query(path: self.path, **kargs, &block) ⇒ Class
Query rely that manages the different blocks.
- #response_class ⇒ Object
Constructor Details
#initialize(client, path: nil, base_path: []) ⇒ BaseQuery
Returns a new instance of BaseQuery.
36 37 38 39 40 |
# File 'lib/ecoportal/api/graphql/logic/base_query.rb', line 36 def initialize(client, path: nil, base_path: []) @path = path @base_path = base_path @client = client end |
Instance Attribute Details
#base_path ⇒ Object (readonly)
Returns the value of attribute base_path.
34 35 36 |
# File 'lib/ecoportal/api/graphql/logic/base_query.rb', line 34 def base_path @base_path end |
#client ⇒ Object (readonly)
Returns the value of attribute client.
33 34 35 |
# File 'lib/ecoportal/api/graphql/logic/base_query.rb', line 33 def client @client end |
Class Method Details
.accepted_params(*keys) ⇒ Object
10 11 12 13 14 |
# File 'lib/ecoportal/api/graphql/logic/base_query.rb', line 10 def accepted_params(*keys) @accepted_params ||= [] return @accepted_params if keys.empty? @accepted_params.push(*keys).tap {|ks| ks.uniq!} end |
.clear_accepted_params ⇒ Object
16 17 18 |
# File 'lib/ecoportal/api/graphql/logic/base_query.rb', line 16 def clear_accepted_params @accepted_params = [] end |
.field_name(str = nil) ⇒ Object
Note:
it is meant for reusability of queries from different end-points
Used to obtain the full path in the GraphQL query by using base_path
26 27 28 29 30 |
# File 'lib/ecoportal/api/graphql/logic/base_query.rb', line 26 def field_name(str = nil) return @field_name unless str @field_name = nil @field_name = str.to_s if str end |
.slice_params(kargs) ⇒ Object
20 21 22 |
# File 'lib/ecoportal/api/graphql/logic/base_query.rb', line 20 def slice_params(kargs) kargs.slice(*accepted_params) end |
Instance Method Details
#access_point(path = []) ⇒ Object
60 61 62 |
# File 'lib/ecoportal/api/graphql/logic/base_query.rb', line 60 def access_point(path = []) path.last end |
#path(field_name = self.class.field_name) ⇒ Object
Resolves the path by using path or base_path + class.field_name.
43 44 45 46 47 48 |
# File 'lib/ecoportal/api/graphql/logic/base_query.rb', line 43 def path(field_name = self.class.field_name) result = @path result ||= default_path if self.respond_to?(:default_path, true) result ||= (base_path + [field_name]) if base_path && field_name result end |
#query(path: self.path, **kargs, &block) ⇒ Class
Query rely that manages the different blocks.
52 53 54 |
# File 'lib/ecoportal/api/graphql/logic/base_query.rb', line 52 def query(path: self.path, **kargs, &block) graphql_query(path: path, **kargs, &basic_block(&block)) end |
#response_class ⇒ Object
56 57 58 |
# File 'lib/ecoportal/api/graphql/logic/base_query.rb', line 56 def response_class raise "You should override this method in #{self.class}" end |