Class: Ecoportal::API::GraphQL::Model::Template::ChangeLogEntry
- Inherits:
-
Base::Template::ChangeLogEntry
- Object
- Common::Content::DoubleModel
- Common::GraphQL::Model
- Logic::BaseModel
- Base::Template::ChangeLogEntry
- Ecoportal::API::GraphQL::Model::Template::ChangeLogEntry
- Defined in:
- lib/ecoportal/api/graphql/model/template/change_log_entry.rb
Overview
Concrete read model for one entry of a template's change log. Adds the relational
embed on top of the interface fields modelled in Base::Template::ChangeLogEntry
(which is where the platform caveats are documented — read them before using this).
Constant Summary
Constants inherited from Base::Template::ChangeLogEntry
Base::Template::ChangeLogEntry::DETAIL_KINDS
Constants included from Common::GraphQL::Model::Diffable
Common::GraphQL::Model::Diffable::DIFF_CLASS
Method Summary
Methods inherited from Base::Template::ChangeLogEntry
#changes, #detail?, #detail_kind
Methods included from Concerns::SnakeCamelAccess
#method_missing, #respond_to_missing?
Methods included from Common::GraphQL::Model::AsInput
Methods included from Common::GraphQL::Model::Diffable
Methods included from Common::GraphQL::ClassHelpers
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Ecoportal::API::GraphQL::Concerns::SnakeCamelAccess